<?php

namespace Service\Per;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use Teknisa\Model\Geral\Entities\Lista;
use Util\Utilities;

class Per
{
    /** @var \Doctrine\DBAL\Connection */
    protected $connection;

    /** @var \Util\Utilities */
    protected $environment;
    /**
     * @var EntityManager
     */
    protected $entityManager;
    /**
     * @var int
     */
    protected $nrorg;
    protected $nrlista;
    /**
     * @var int|string
     */
    protected $nrtrabgerapers;
    protected $cdOperador;
    protected $cdcliente;
    /**
     * @var \DateTime
     */
    protected $now;

    public function __construct()
    {

        $this->entityManager = Utilities::getEntityManager();
        $this->connection = $this->entityManager->getConnection();
        $this->environment = Utilities::getEnvironment();
        $this->nrorg = $this->environment->getCurrentOrganizationId();
        $this->nrlista = null;
        $this->nrtrabgerapers = null;
        $this->now = new \DateTime();
        //$this->now = $now->format('d/m/Y');
        $this->cdOperador = $this->environment->getCurrentUserId();
        $this->cdcliente = $this->environment->getCurrentCdCliente();
    }

    public function getLimSemPer($licencausoArray)
    {

        try {
            $this->connection->beginTransaction();
            $this->nrlista = Utilities::getCodeByTableName('LISTAFILIAL', $this->nrorg);
            $this->nrtrabgerapers = Utilities::getCodeByTableName('LISTATRAB', $this->nrorg);
            $stControle = null;
            foreach ($licencausoArray as $licencauso) {
                $this->acmInsListaFilial($licencauso);
            }
            $adqTipoFatCli = $this->adqTipoFatCli();
            $adqLinProdSemPerArray = $this->adqLinProdSemPer();
            $this->setListaTrab($adqLinProdSemPerArray, $adqTipoFatCli, false);

            $adqLinProdSemPerPtoArray = $this->adqLinProdSemPerPto();

            $this->setListaTrab($adqLinProdSemPerPtoArray, $adqTipoFatCli);

             $this->connection->commit();

            return array('listaFili' => $this->nrlista, 'listaTrab' => $this->nrtrabgerapers);

        } catch (\Exception $e) {
             $this->connection->rollBack();
            throw $e;
        }

    }

    protected function acmInsListaFilial($cdlista)
    {

        $insert = <<<SQL
        INSERT INTO LISTA
            (NRLISTA, CDLISTA, DTULTATULIST, NRORG, DTINCLUSAO, DTULTATU,CDOPERINCLUSAO,CDOPERULTATU)
        VALUES
            (:NRLISTA, :NRLICENCAUSO, SYSDATE, :NRORG, SYSDATE, SYSDATE, :OPER, :OPER)
SQL;
        $params = array(
            'NRLISTA' => $this->nrlista,
            'OPER' => $this->cdOperador,
            'NRLICENCAUSO' => str_pad($cdlista, 10, "0", STR_PAD_LEFT),
            'NRORG' => $this->nrorg
        );

        return $this->connection->executeQuery($insert, $params);

    }

    protected function adqTipoFatCli()
    {
        $query = <<<SQL
        SELECT NVL(IDUTLICEUSO,'S') AS IDUTLICEUSO
          FROM CLIENTE
         WHERE CDCLIENTE = :P_CDCLIENTE
SQL;
        $params = array(
            'P_CDCLIENTE' => $this->cdcliente
        );
        return $this->connection->fetchAll($query, $params);
    }

    protected function adqLinProdSemPer()
    {
        $query = <<<SQL
        SELECT LL.CDCLIENTE, LL.CDLINPCLIE, LL.NRLICENCAUSO, ' ' IDLUSOPAGA,
       LL.DTINCLUSAO, QV.IDTIPLINPC, QV.QTMINIMAFATLINP,
       QV.QTVALIDAS, QV.VRLICENCUSOLINP, QV.VRMENSALIDALINP
  FROM LINPLUSO LL, LISTA LI,
       (SELECT CLP.CDCLIENTE, CLP.CDLINPCLIE, CLP.IDTIPLINPC,
               NVL(CLP.QTMINIMAFATLINP, 0) QTMINIMAFATLINP, NVL(QTV.QTVALIDAS, 0) QTVALIDAS,
               NVL(VLR.VRLICENCUSOLINP, 0) VRLICENCUSOLINP, NVL(VLR.VRMENSALIDALINP, 0)  VRMENSALIDALINP
          FROM CONTRATOLINP CLP,
               (SELECT LL.CDCLIENTE, LL.CDLINPCLIE, COUNT(*) AS QTVALIDAS
                  FROM LICENCAUSO LU, LINPLUSO LL, CONTRATOLINP CL
                 WHERE LL.CDCLIENTE = :P_CDCLIENTE
                   AND LU.CDCLIENTE = LL.CDCLIENTE
                   AND LU.NRLICENCAUSO = LL.NRLICENCAUSO
                   AND CL.CDCLIENTE = LL.CDCLIENTE
                   AND CL.CDLINPCLIE = LL.CDLINPCLIE
                   AND CL.IDTIPLINPC IN ('M', 'L')
                   AND CL.DTCONTLINPRESC IS NULL
                   AND SITUACAO_LINPLUSO (LU.IDLUSOATIV, LL.DTVALPERSLUPEND, LL.DTVALPERSLUPAGA, LL.IDLINPEXCLUIDA, SYSDATE, 'VALIDA') = 'VALIDA'
                 GROUP BY LL.CDCLIENTE, LL.CDLINPCLIE) QTV,
               (SELECT VL.CDCLIENTE, VL.CDLINPCLIE, VL.VRLICENCUSOLINP,
                       VL.VRMENSALIDALINP, VL.DTFVIGVRLINP, VL.DTIVIGVRLINP
                  FROM VALORLINP VL
                 WHERE VL.CDCLIENTE = :P_CDCLIENTE
                   AND VL.DTIVIGVRLINP = (SELECT MAX(DTIVIGVRLINP)
                                            FROM VALORLINP VI
                                           WHERE VI.CDCLIENTE  = VL.CDCLIENTE
                                             AND VI.CDLINPCLIE = VL.CDLINPCLIE)) VLR
         WHERE CLP.CDCLIENTE = :P_CDCLIENTE
           AND CLP.IDTIPLINPC IN ('M', 'L')
           AND CLP.DTCONTLINPRESC IS NULL
           AND QTV.CDCLIENTE (+) = CLP.CDCLIENTE
           AND QTV.CDLINPCLIE (+) = CLP.CDLINPCLIE
           AND VLR.CDCLIENTE (+) = CLP.CDCLIENTE
           AND VLR.CDLINPCLIE (+) = CLP.CDLINPCLIE) QV
 WHERE LI.NRLISTA = :P_NRLISTA
   AND LL.CDCLIENTE = :P_CDCLIENTE
   AND LL.NRLICENCAUSO = LI.CDLISTA
   AND QV.CDCLIENTE = LL.CDCLIENTE
   AND QV.CDLINPCLIE = LL.CDLINPCLIE
   AND LL.DTVALPERSLUPEND IS NULL
   AND LL.DTVALPERSLUPAGA IS NULL
 ORDER BY LL.CDCLIENTE, LL.CDLINPCLIE, LL.DTINCLUSAO, LL.NRLICENCAUSO
SQL;
        $params = array(
            'P_CDCLIENTE' => $this->cdcliente,
            'P_NRLISTA' => $this->nrlista
        );
        return $this->connection->fetchAll($query, $params);
    }

    protected function acmInsLinSemPer($nrlicencusopers, $cdlinpcliepers, $cdcaixalusopers, $idlusopaga)
    {

        $insert = <<<SQL
        INSERT INTO TRABGERAPERS
           (NRTRABGERAPERS, CDCLIENTEPERS, NRLICENCUSOPERS, CDLINPCLIEPERS, CDCAIXALUSOPERS, IDLUSOPAGA,CDOPERINCLUSAO,CDOPERULTATU)
        VALUES
           (:NRTRABGERAPERS, :CDCLIENTEPERS, :NRLICENCUSOPERS, :CDLINPCLIEPERS, :CDCAIXALUSOPERS, :IDLUSOPAGA, :P_OPER, :P_OPER)
SQL;
        $params = array(
            'NRTRABGERAPERS' => $this->nrtrabgerapers,
            'CDCLIENTEPERS' => $this->cdcliente,
            'NRLICENCUSOPERS' => $nrlicencusopers,
            'CDLINPCLIEPERS' => $cdlinpcliepers,
            'CDCAIXALUSOPERS' => $cdcaixalusopers,
            'IDLUSOPAGA' => $idlusopaga,
            'P_OPER' => $this->cdOperador,
        );
        $this->connection->executeQuery($insert, $params);
    }

    protected function adqLinProdSemPerPto()
    {
        $query = <<<SQL
       SELECT LL.CDCLIENTE, LL.CDLINPCLIE, CX.NRLICENCAUSO, CX.CDCAIXALUSO, ' ' IDLUSOPAGA,
       CX.DTINCLUSAO, QV.IDTIPLINPC, QV.QTMINIMAFATLINP,
       QV.QTVALIDAS, QV.VRLICENCUSOLINP, QV.VRMENSALIDALINP
  FROM LINPLUSO LL, CAIXALUSO CX, LISTA LI,
       (SELECT CLP.CDCLIENTE, CLP.CDLINPCLIE, CLP.IDTIPLINPC,
               NVL(CLP.QTMINIMAFATLINP, 0) QTMINIMAFATLINP, NVL(QTV.QTVALIDAS, 0) QTVALIDAS,
               NVL(VLR.VRLICENCUSOLINP, 0) VRLICENCUSOLINP, NVL(VLR.VRMENSALIDALINP, 0)  VRMENSALIDALINP
          FROM CONTRATOLINP CLP,
               (SELECT LL.CDCLIENTE, LL.CDLINPCLIE, COUNT(*) AS QTVALIDAS
                  FROM LICENCAUSO LU, LINPLUSO LL, CAIXALUSO CX, CONTRATOLINP CL
                 WHERE LL.CDCLIENTE = :P_CDCLIENTE
                   AND LU.CDCLIENTE = LL.CDCLIENTE
                   AND LU.NRLICENCAUSO = LL.NRLICENCAUSO
                   AND CL.CDCLIENTE = LL.CDCLIENTE
                   AND CL.CDLINPCLIE = LL.CDLINPCLIE
                   AND CL.IDTIPLINPC IN ('P', 'A')
                   AND CL.DTCONTLINPRESC IS NULL
                   AND CX.CDCLIENTE = LU.CDCLIENTE
                   AND CX.NRLICENCAUSO = LU.NRLICENCAUSO
                   AND SITUACAO_LINPLUSO (LU.IDLUSOATIV, CX.DTVALPERSCXPEND, CX.DTVALPERSCXPAGO, CX.IDCAIXAEXCLUIDO, SYSDATE, 'VALIDA') = 'VALIDA'
                 GROUP BY LL.CDCLIENTE, LL.CDLINPCLIE) QTV,
               (SELECT VL.CDCLIENTE, VL.CDLINPCLIE, VL.VRLICENCUSOLINP,
                       VL.VRMENSALIDALINP, VL.DTFVIGVRLINP, VL.DTIVIGVRLINP
                  FROM VALORLINP VL
                 WHERE VL.CDCLIENTE = :P_CDCLIENTE
                   AND VL.DTIVIGVRLINP = (SELECT MAX(DTIVIGVRLINP)
                                            FROM VALORLINP VI
                                           WHERE VI.CDCLIENTE  = VL.CDCLIENTE
                                             AND VI.CDLINPCLIE = VL.CDLINPCLIE)) VLR
         WHERE CLP.CDCLIENTE = :P_CDCLIENTE
           AND CLP.IDTIPLINPC IN ('P', 'A')
           AND CLP.DTCONTLINPRESC IS NULL
           AND QTV.CDCLIENTE (+) = CLP.CDCLIENTE
           AND QTV.CDLINPCLIE (+) = CLP.CDLINPCLIE
           AND VLR.CDCLIENTE (+) = CLP.CDCLIENTE
           AND VLR.CDLINPCLIE (+) = CLP.CDLINPCLIE) QV
 WHERE LI.NRLISTA = :P_NRLISTA
   AND LL.CDCLIENTE = :P_CDCLIENTE
   AND LL.NRLICENCAUSO = LI.CDLISTA
   AND QV.CDCLIENTE = LL.CDCLIENTE
   AND QV.CDLINPCLIE = LL.CDLINPCLIE
   AND CX.CDCLIENTE = LL.CDCLIENTE
   AND CX.NRLICENCAUSO = LL.NRLICENCAUSO
   AND CX.DTVALPERSCXPEND IS NULL
   AND CX.DTVALPERSCXPAGO IS NULL
 ORDER BY LL.CDCLIENTE, LL.CDLINPCLIE, CX.DTINCLUSAO, LL.NRLICENCAUSO, CX.CDCAIXALUSO
SQL;
        $params = array(
            'P_CDCLIENTE' => $this->cdcliente,
            'P_NRLISTA' => $this->nrlista
        );
        return $this->connection->fetchAll($query, $params);
    }

    /**
     * @param array $adqLinProdSemPerArray
     * @param array $adqTipoFatCli
     * @param $setcaixa
     */
    private function setListaTrab(array $adqLinProdSemPerArray, array $adqTipoFatCli, $setcaixa = true)
    {
        $stCdLInp = '';
        $inCountPaga = 0;
        $stControle = null;
        foreach ($adqLinProdSemPerArray as $adqLinProdSemPer) {
            $stCdLInp = $adqLinProdSemPer['CDLINPCLIE'];
            $dbValidas = intval($adqLinProdSemPer['QTVALIDAS']);
            if ($stCdLInp != $stControle) {
                $inCountPaga = 0;
            }
            $stControle = $adqLinProdSemPer['CDLINPCLIE'];
            $idlusopaga = null;
            if (((($dbValidas + $inCountPaga) < $adqLinProdSemPer['QTMINIMAFATLINP']) || ($adqLinProdSemPer['IDTIPLINPC'] == 'L')) ||
                ($adqTipoFatCli['IDUTLICEUSO'] == 'N')) {
                $inCountPaga++;
                $idlusopaga = 'S';
            } else {
                $idlusopaga = 'N';
            }
            $cdcaixalusopers = null;
            if($setcaixa){
                $cdcaixalusopers = $adqLinProdSemPer['CDCAIXALUSO'];
            }
            $this->acmInsLinSemPer($adqLinProdSemPer['NRLICENCAUSO'],
                $adqLinProdSemPer['CDLINPCLIE'], $cdcaixalusopers, $idlusopaga);
        }
    }
}
