/*
Tecnisa - Tecnologia em Informtica

Nome: APURAC_VENC

Descrio:
   Procedimento para criao dos vencimentos da NF
   de acordo com a forma de pagamento do cliente, fornecedor, pedido,
   licena de uso ou autorizao de fornecimento.

Criao:
26/11/99 - Roberto A. Lopes Martins

@C:\web_560\sql\end_conv\oracle\0008_GERSTPO_APURACVENC.sql

PARA DEBUGAR PROCEDURE            
raise_application_error(-20501, '' , True);

Procedure para gerao de contas a receber */

CREATE OR REPLACE PROCEDURE APURAC_VENC(
         P_CDFILIAL   IN FILIAL.CDFILIAL%TYPE,
         P_CDCLIENTE  IN CLIENTE.CDCLIENTE%TYPE,
         P_NRLANCTONF IN NOTAFISCAL.NRLANCTONF%TYPE)

AS

   V_CDFILIALPED   ITEMPRODUTO.CDFILIALPED%TYPE;
   V_NRPEDIDO      ITEMPRODUTO.NRPEDIDO%TYPE;
   V_FORMPGTOCL    CLIENTE.IDTPFORPGTCL%TYPE;
   V_PARCPGTOCL    CLIENTE.NRPARCPGTOCL%TYPE;
   V_VRNOTAFISC    NOTAFISCAL.VRNOTAFISC%TYPE;
   V_CDINTEGRACAO  NOTAFISCAL.CDINTEGRACAO%TYPE;
   V_CDFILIEMIT    NOTAFISCAL.CDFILIEMIT%TYPE;

   V_COUNT         NUMBER;

   V_VRTOTIMPONF   NUMBER;
   
   V_VRTOTIMPONFPR NUMBER;

   V_ORIGDESTNF    VARCHAR2(01);
   V_ENTRSAIDOP    VARCHAR2(01);

   V_VRIMPORETI    NUMBER;
   V_SEQUENCIAL    NUMBER;
   V_VRPARCVENC    NUMBER;
   V_VRPARCAUXI    NUMBER;
   V_NRPARCELAS    NUMBER;

   V_CDSERVCONT    SERVCONTRAT.CDSERVCONT%TYPE;
   V_DSREFSERVFAT  SERVFATU.DSREFSERVFAT%TYPE;

   V_CDFILIALDUP   CONTARECEBER.CDFILIALDUP%TYPE;
   V_NRLANCTODUP   CONTARECEBER.NRLANCTODUP%TYPE;

   V_VRCONTARECE   CONTARECEBER.VRATUAREC%TYPE;

   V_VRIMPOSRETI   TRABIMPOSNFTOT.VRIMPOSTOT%TYPE;
   V_ARAJUSTEDUP   AJDUPBOLET.VRAJDUPBOLET%TYPE;
   V_CDAJUCTREC    AJDUPBOLET.CDAJUCTREC%TYPE;
   V_IDCONTAIMPOSTO CONTARECEBER.IDCONTAIMPOSTO%TYPE;

   V_SEQUENCIALST  NUMBER;

   w_A             Char(1):= 'A';
   w_R             Char(1):= 'R';
   w_D             Char(1):= 'D';
   w_N             Char(1):= 'N';
   w_C             Char(1):= 'C'; /* Cliente */
   w_S             Char(1):= 'S';
   w_F             Char(1):= 'F'; /* Fornecedor */
   w_U             Char(1):= 'U'; /* Usado pela Teknisa (Nota de servio) */
   w_0             ChaR(1):= '0';
   w_00            ChaR(2):= '00';
   w_01            ChaR(2):= '01';

BEGIN
   V_VRTOTIMPONF   := 0;
   V_VRTOTIMPONFPR := 0;
   V_SEQUENCIALST  := 0;

   Begin
      SELECT VRNOTAFISC,   NVL(IDORIGDESTNF,w_C), IDENTRSAIDOP, CDINTEGRACAO,   CDFILIEMIT
      INTO   V_VRNOTAFISC, V_ORIGDESTNF,          V_ENTRSAIDOP, V_CDINTEGRACAO, V_CDFILIEMIT
      FROM NOTAFISCAL
      WHERE (CDFILIAL   = P_CDFILIAL) AND
            (NRLANCTONF = P_NRLANCTONF);
   Exception
      When No_Data_Found Then
         V_VRNOTAFISC := 0; V_ORIGDESTNF := w_C; V_ENTRSAIDOP := Null; V_CDINTEGRACAO := Null; V_CDFILIEMIT := Null;
   End;

   IF V_CDINTEGRACAO IS NULL THEN
      SELECT SUM(VRTOTIMPONF)
      INTO   V_VRIMPORETI
      FROM IMPOSNFTOT INF, IMPOSTO I
      WHERE INF.CDFILIAL   = P_CDFILIAL   AND
            INF.NRLANCTONF = P_NRLANCTONF AND
            INF.CDIMPOSTO  = I.CDIMPOSTO  AND
            I.IDDESCRFONTE <> w_A         AND
            I.IDTRATIMPO   = w_R;
   ELSE

      SELECT NVL(SUM(IT.VRIMPOSTOT),0)
      INTO   V_VRIMPORETI
      FROM TRABIMPOSNFTOT IT, IMPOSTO I
      WHERE I.CDIMPOSTO     = IT.CDIMPOSTOT AND
            IT.CDFILIMPTOT  = P_CDFILIAL    AND
            IT.NRLANCIMPTOT = P_NRLANCTONF  AND
            I.IDDESCRFONTE  <> w_A          AND
            I.IDTRATIMPO    = w_R;
   END IF;

   IF (V_VRIMPORETI IS NULL) THEN
      V_VRIMPORETI := 0;
   END IF;

   V_VRNOTAFISC := ROUND(V_VRNOTAFISC - V_VRIMPORETI,2);

   IF V_ENTRSAIDOP = w_S THEN
      SELECT MAX(I.CDFILIALPED), MAX(NRPEDIDO)
      INTO V_CDFILIALPED, V_NRPEDIDO
      FROM ITEMPRODUTO I
      WHERE I.CDFILIAL   = P_CDFILIAL AND
            I.NRLANCTONF = P_NRLANCTONF;
   ELSE
      V_CDFILIALPED := NULL;
   END IF;

   IF V_CDFILIALPED IS NULL THEN
      IF (V_ORIGDESTNF = w_F) THEN
         Begin
           SELECT F.IDTPFORPGTFO, F.NRPARCPGTOFO
           INTO   V_FORMPGTOCL,   V_PARCPGTOCL
           FROM FORNECEDOR F
           WHERE F.CDFORNECED = P_CDCLIENTE;
         Exception
            When No_Data_Found Then
               V_FORMPGTOCL := Null;  V_PARCPGTOCL := Null;
         End;

      ELSIF V_ORIGDESTNF = w_U THEN
         SELECT MAX(CDSERVCONT), MAX(DSREFSERVFAT)
         INTO   V_CDSERVCONT,    V_DSREFSERVFAT
         FROM SERVFATU
         WHERE (CDFILIAL   = P_CDFILIAL) AND
               (NRLANCTONF = P_NRLANCTONF);

         Begin
           SELECT S.IDTPFORPGTSC, S.NRPARCPGTOSC
           INTO   V_FORMPGTOCL,   V_PARCPGTOCL
           FROM SERVCONTRAT S
           WHERE (S.CDCLIENTE  = P_CDCLIENTE) AND
                 (S.CDSERVCONT = V_CDSERVCONT);
         Exception
            When No_Data_Found Then
               V_FORMPGTOCL := Null; V_PARCPGTOCL := Null;
         End;

      ELSE
         Begin
           SELECT C.IDTPFORPGTCL, C.NRPARCPGTOCL
           INTO   V_FORMPGTOCL,   V_PARCPGTOCL
           FROM CLIENTE C
           WHERE C.CDCLIENTE = P_CDCLIENTE;
         Exception
            When No_Data_Found Then
               V_FORMPGTOCL := Null; V_PARCPGTOCL := Null;
         End;

      END IF;
   ELSE
      Begin
        SELECT P.IDTPFORPGTPED, P.NRPARCPGTOPED
        INTO   V_FORMPGTOCL,    V_PARCPGTOCL
        FROM PEDIDO P
        WHERE P.CDFILIAL = V_CDFILIALPED AND
              P.NRPEDIDO = V_NRPEDIDO;
      Exception
        When No_Data_Found Then
           V_FORMPGTOCL := Null; V_PARCPGTOCL := Null;
      End;

   END IF;

/*
  Incluso na tabela de contas a receber de acordo com a forma de pagamento do cliente
*/

   SELECT MAX(CDFILIALDUP), MAX(NRLANCTODUP)
   INTO   V_CDFILIALDUP,    V_NRLANCTODUP
   FROM CONTARECEBER
   WHERE CDFILIAL   = P_CDFILIAL AND
         NRLANCTONF = P_NRLANCTONF;

   IF V_NRLANCTODUP IS NOT NULL THEN
      SELECT SUM(VRATUAREC)
      INTO   V_VRCONTARECE
      FROM CONTARECEBER
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRLANCTONF = P_NRLANCTONF;

      UPDATE DUPLICATA
      SET VRDUPLICATA = VRDUPLICATA - V_VRCONTARECE
      WHERE CDFILIAL    = V_CDFILIALDUP AND
            NRLANCTODUP = V_NRLANCTODUP;
   END IF;

   DELETE CONTARECEBER
   WHERE CDFILIAL   = P_CDFILIAL AND
         NRLANCTONF = P_NRLANCTONF;

   /*BUSCA  VALOR DO IMPOSTO ACRESCER PARA SOMAR NA PRIMEIRA PARCELA */
   Begin
      SELECT NVL(SUM(N.VRTOTIMPONF), 0)
        INTO V_VRTOTIMPONFPR
        FROM IMPOSNFTOT N, IMPOSTO I
       WHERE N.CDFILIAL = P_CDFILIAL
         AND N.NRLANCTONF = P_NRLANCTONF
         AND N.CDIMPOSTO= I.CDIMPOSTO
         AND I.IDTRATIMPO = 'A'
         AND IDGERAPARCFIN = 'P';
   Exception
      When No_Data_Found Then
         V_VRTOTIMPONFPR := 0;
   End;

   /*BUSCA SE EXISTE ALGUEM IMPOSTO ACRESCER PARA GERAR PARCELA SEPADARA*/
   Begin
      SELECT COUNT(1)
        INTO V_COUNT
        FROM IMPOSNFTOT IT, IMPOSTO I
       WHERE IT.CDFILIAL = P_CDFILIAL
         AND IT.NRLANCTONF = P_NRLANCTONF
         AND IT.CDIMPOSTO= I.CDIMPOSTO
         AND I.IDTRATIMPO = 'A'
         AND I.IDGERAPARCFIN = 'S';
   Exception
      When No_Data_Found Then
         V_COUNT := 0;
   End;

   IF (V_ENTRSAIDOP = w_S) AND (V_COUNT > 0) THEN   /* Gera Parcela de Substituio Tributria*/
      Begin
         SELECT SUM(NVL(N.VRTOTIMPONF, 0))
           INTO V_VRTOTIMPONF
           FROM IMPOSNFTOT N, IMPOSTO I
          WHERE N.CDFILIAL = P_CDFILIAL
            AND N.NRLANCTONF = P_NRLANCTONF
            AND N.CDIMPOSTO= I.CDIMPOSTO
            AND I.IDTRATIMPO = 'A'
            AND IDGERAPARCFIN = 'S';
      Exception
         When No_Data_Found Then
            V_VRTOTIMPONF := 0;
      End;

      IF V_VRTOTIMPONF <> 0 THEN
         V_SEQUENCIALST := 1;
         V_VRPARCVENC := V_VRTOTIMPONF;

         INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                   NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                   IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                           VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIALST),2,w_0),
                                   w_00, 0, NULL, V_VRPARCVENC, NULL, V_VRPARCVENC,
                                   w_A, NULL, NULL, NULL, 'S');
      END IF;
   END IF;

   V_SEQUENCIAL := 1;

   IF (V_FORMPGTOCL IS NULL) THEN   /*Sem forma de pagamento definida*/
      V_VRNOTAFISC := V_VRNOTAFISC - V_VRTOTIMPONF;
      INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
           VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0), w_00,  0, NULL,
                   V_VRNOTAFISC, NULL, V_VRNOTAFISC, w_A, NULL, NULL, NULL, 'N');

   ELSIF (V_FORMPGTOCL = w_F) THEN   /*Forma de pagamento fixa*/
      V_VRNOTAFISC := V_VRNOTAFISC - V_VRTOTIMPONF;
      IF (V_PARCPGTOCL = 1) THEN   /* Uma parcela */

         INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                   NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                   IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
              VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0), w_00, 0, NULL,
                      V_VRNOTAFISC, NULL, V_VRNOTAFISC, w_A, NULL, NULL, NULL, 'N');
      ELSE
         IF (V_ENTRSAIDOP = w_S) THEN  /* Mais de uma parcela */
            V_VRNOTAFISC := V_VRNOTAFISC - V_VRTOTIMPONFPR;
            V_VRPARCVENC := ROUND(V_VRNOTAFISC/V_PARCPGTOCL,2);

            WHILE V_SEQUENCIAL <= V_PARCPGTOCL LOOP
               IF V_SEQUENCIAL = V_PARCPGTOCL THEN
                  V_VRPARCVENC := V_VRPARCVENC + ROUND(V_VRNOTAFISC - (V_VRPARCVENC * V_PARCPGTOCL),2);
               END IF;

               INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                         NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                         IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                    VALUES (P_CDFILIAL, P_NRLANCTONF, NULL,
                            NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0), w_00, 0, NULL,
                             ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), w_A, NULL, NULL, NULL, 'N');

               V_SEQUENCIAL := V_SEQUENCIAL + 1;
            END LOOP;
         END IF;
      END IF;
   ELSE   /*Forma de pagamento varivel*/
      IF V_CDFILIALPED IS NULL THEN
         IF V_ORIGDESTNF = w_F THEN
            SELECT COUNT(*)
            INTO   V_NRPARCELAS
            FROM PRAZOPGTFORN
            WHERE CDFORNECED = P_CDCLIENTE;
         ELSIF V_ORIGDESTNF = w_U THEN
            SELECT COUNT(*)
            INTO   V_NRPARCELAS
            FROM PZPGSERCONT
            WHERE CDCLIENTE  = P_CDCLIENTE AND
                  CDSERVCONT = V_CDSERVCONT;
         ELSE
            SELECT COUNT(*)
            INTO   V_NRPARCELAS
            FROM PRAZOPGTCLIE
            WHERE CDCLIENTE = P_CDCLIENTE;
         END IF;
      ELSE
         SELECT COUNT(*)
         INTO   V_NRPARCELAS
         FROM PRAZOPGTOPED P
         WHERE P.CDFILIAL = V_CDFILIALPED AND
               P.NRPEDIDO = V_NRPEDIDO;
      END IF;

      IF (V_NRPARCELAS = 1) THEN   /* Uma parcela */
         WHILE V_SEQUENCIAL < 2 LOOP
            V_VRPARCVENC := V_VRNOTAFISC - V_VRTOTIMPONF;

            INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                      NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                      IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
            VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0),
                    w_00, 0, NULL, V_VRPARCVENC, NULL, V_VRPARCVENC,
                    w_A, NULL, NULL, NULL, 'N');
            V_SEQUENCIAL := V_SEQUENCIAL + 1;
         END LOOP;
      ELSE   /* Mais de uma parcela */
         V_SEQUENCIAL := 1;
         V_VRPARCAUXI := 0;

         V_VRNOTAFISC := V_VRNOTAFISC - V_VRTOTIMPONF - V_VRTOTIMPONFPR;

         IF V_CDFILIALPED IS NULL THEN
            IF V_ORIGDESTNF = w_F THEN
               FOR C_PARCELAS IN (SELECT VRPERCPGTOFO
                                  FROM PRAZOPGTFORN
                                  WHERE CDFORNECED = P_CDCLIENTE) LOOP

                  V_VRPARCVENC := ROUND((V_VRNOTAFISC * (C_PARCELAS.VRPERCPGTOFO/100)),2);
                  V_VRPARCAUXI := V_VRPARCAUXI + V_VRPARCVENC;

                  IF (V_ENTRSAIDOP = w_S) AND (V_COUNT > 0) AND (V_VRTOTIMPONF <> 0) THEN
                     IF (V_SEQUENCIAL - 1) = V_NRPARCELAS THEN
                        V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                     END IF;
                  ELSE
                     IF V_SEQUENCIAL = V_NRPARCELAS THEN
                        V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                     END IF;
                  END IF;

                  INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                            NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                            IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                  VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0),
                          w_00, 0, NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), w_A, NULL, NULL, NULL, 'N');

                  V_SEQUENCIAL := V_SEQUENCIAL + 1;
               END LOOP;
            ELSIF V_ORIGDESTNF = w_U THEN
               FOR C_PARCELAS IN (SELECT VRPERCPGTOSC AS VRPERCPGTOCL
                                  FROM PZPGSERCONT
                                  WHERE CDCLIENTE  = P_CDCLIENTE AND
                                        CDSERVCONT = V_CDSERVCONT) LOOP

                  V_VRPARCVENC := ROUND((V_VRNOTAFISC * (C_PARCELAS.VRPERCPGTOCL/100)),2);
                  V_VRPARCAUXI := V_VRPARCAUXI + V_VRPARCVENC;

                  IF V_SEQUENCIAL = V_NRPARCELAS THEN
                     V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                  END IF;

                  INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                            NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                            IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                  VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0),
                          w_00, 0, NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), w_A, V_DSREFSERVFAT, NULL, NULL, 'N');

                  V_SEQUENCIAL := V_SEQUENCIAL + 1;
               END LOOP;
            ELSE
               FOR C_PARCELAS IN (SELECT VRPERCPGTOCL
                                  FROM PRAZOPGTCLIE
                                  WHERE CDCLIENTE = P_CDCLIENTE) LOOP

                  V_VRPARCVENC := ROUND((V_VRNOTAFISC * (C_PARCELAS.VRPERCPGTOCL/100)),2);
                  V_VRPARCAUXI := V_VRPARCAUXI + V_VRPARCVENC;

                  IF (V_ENTRSAIDOP = w_S) AND (V_COUNT > 0) AND (V_VRTOTIMPONF <> 0) THEN
                     IF (V_SEQUENCIAL - 1) = V_NRPARCELAS THEN
                        V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                     END IF;
                  ELSE
                     IF V_SEQUENCIAL = V_NRPARCELAS THEN
                        V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                     END IF;
                  END IF;

                  INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                            NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                            IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                  VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0),
                          w_00, 0, NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), w_A, NULL, NULL, NULL, 'N');

                  V_SEQUENCIAL := V_SEQUENCIAL + 1;
               END LOOP;
            END IF;
         ELSE
            FOR C_PARCELAS IN (SELECT VRPERCPGTOPED
                               FROM PRAZOPGTOPED P
                               WHERE P.CDFILIAL = V_CDFILIALPED AND
                                     P.NRPEDIDO = V_NRPEDIDO) LOOP

               V_VRPARCVENC := ROUND((V_VRNOTAFISC * (C_PARCELAS.VRPERCPGTOPED/100)),2);
               V_VRPARCAUXI := V_VRPARCAUXI + V_VRPARCVENC;

               IF (V_ENTRSAIDOP = w_S) AND (V_COUNT > 0) AND (V_VRTOTIMPONF <> 0) THEN
                  IF (V_SEQUENCIAL - 1) = V_NRPARCELAS THEN
                     V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                  END IF;
               ELSE
                  IF V_SEQUENCIAL = V_NRPARCELAS THEN
                     V_VRPARCVENC := V_VRPARCVENC + ROUND((V_VRNOTAFISC - V_VRPARCAUXI),2);
                  END IF;
               END IF;


               INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                         NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                         IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
               VALUES (P_CDFILIAL, P_NRLANCTONF, NULL, NULL, NULL, LPAD(TO_CHAR(V_SEQUENCIAL+V_SEQUENCIALST),2,w_0),
                       w_00, 0, NULL, ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), NULL,  ROUND(DECODE(V_SEQUENCIAL, 1, V_VRPARCVENC+V_VRTOTIMPONFPR, V_VRPARCVENC), 2), w_A, NULL, NULL, NULL, 'N');

               V_SEQUENCIAL := V_SEQUENCIAL + 1;
            END LOOP;
         END IF;
      END IF;
   END IF;

   IF V_NRLANCTODUP IS NOT NULL THEN
      UPDATE CONTARECEBER
      SET CDFILIALDUP = V_CDFILIALDUP,
          NRLANCTODUP = V_NRLANCTODUP
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRLANCTONF = P_NRLANCTONF;

      SELECT SUM(VRATUAREC)
      INTO   V_VRCONTARECE
      FROM CONTARECEBER
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRLANCTONF = P_NRLANCTONF;

      UPDATE DUPLICATA
      SET VRDUPLICATA = VRDUPLICATA + V_VRCONTARECE
      WHERE CDFILIAL    = V_CDFILIALDUP AND
            NRLANCTODUP = V_NRLANCTODUP;

      SELECT NVL(SUM(IT.VRIMPOSTOT),0)
      INTO   V_VRIMPOSRETI
      FROM TRABIMPOSNFTOT IT, IMPOSTO I
      WHERE I.CDIMPOSTO     = IT.CDIMPOSTOT AND
            IT.CDFILIMPTOT  = P_CDFILIAL    AND
            IT.NRLANCIMPTOT = P_NRLANCTONF  AND
            I.IDDESCRFONTE  <> w_A          AND
            I.IDTRATIMPO    = w_R;

      SELECT NVL(MAX(A.VRAJDUPBOLET),0), MAX(T.CDAJUCTREC)
      INTO   V_ARAJUSTEDUP,              V_CDAJUCTREC
      FROM AJDUPBOLET A, TIPOAJRECEBER T
      WHERE A.CDFILIAL    = V_CDFILIALDUP AND
            A.NRLANCTODUP = V_NRLANCTODUP AND
            A.CDAJUCTREC  = T.CDAJUCTREC  AND
            T.IDAJUCTREC  = w_D;

      IF V_ARAJUSTEDUP > 0 THEN
         IF V_ARAJUSTEDUP > V_VRIMPOSRETI THEN
            UPDATE AJDUPBOLET
            SET VRAJDUPBOLET = VRAJDUPBOLET - V_VRIMPOSRETI
            WHERE CDFILIAL    = V_CDFILIALDUP AND
                  NRLANCTODUP = V_NRLANCTODUP AND
                  CDAJUCTREC  = V_CDAJUCTREC;

         ELSIF (V_ARAJUSTEDUP = V_VRIMPOSRETI) THEN
            DELETE AJDUPBOLET
            WHERE CDFILIAL    = V_CDFILIALDUP AND
                  NRLANCTODUP = V_NRLANCTODUP AND
                  CDAJUCTREC  = V_CDAJUCTREC;
         END IF;
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('APURAC_VENC','5.60.xxx'); END;
/

